@@ -1,7 +1,7 @@
 
 APPLICATION_NAME = "DevSecOps utilty"
 REGEX_PATTERNS = {
-    'context' : r"^([a-zA-Z][a-zA-Z0-9]+)/?([a-zA-Z0-9]*)?$",
+    'stage' : r"^([a-zA-Z][a-zA-Z0-9]+)/?([0-9])?$",
     'parameter_key' : r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$",
     'parameter_key_value' : r"^([a-zA-Z][a-zA-Z0-9_.-/]*)=(.*)$",
 }
@@ -43,14 +43,14 @@ CLI_COMMANDS_SHORT_HELP = {
         'get': "Get DSO application configuration(s).",
         'set': "Set the DSO application configuration(s).",
         'delete': "Delete a DSO application configuration.",
-        'setup': "Run the setup wizard to configure the DSO application.",
+        'init': "Initialize DSO configuration for the working directory.",
     },
 }
 CLI_PARAMETERS_HELP = {
     'common': {
         'working_dir': "Path to the directory where the DSO application configuration resides. Current working directory will be used by default.",
-        'verbosity' : "Logging verbosity: 0 for errors, 1 for warnings, 2 for information, 3 for debug, 4 for everything.",
-        'context' : "Name of the context, which is combination of a stage and an environment. if no <env> is specefied, the default environment in the given stage will be used.",
+        'verbosity' : "Logging verbosity: 0 for criticals, 1 for errors, 2 for warnings, 3 for information, 4 for debug, 5 for everything.",
+        'stage' : f"Identifier of the stage, which is combination of a name and an optional number as in <name>[/<number>], and it must conform to '{REGEX_PATTERNS['stage']}'. If no <number> is specefied, the default environment (0) in the given stage will be used.",
         'input' : "Path to a local file inputing the parameters. Use '-' to read from pipe/stdin.",
         'format' : "Data format",
         'config': "Comma separated list of key:value pairs to override DSO configurations.",
@@ -71,13 +71,18 @@ CLI_PARAMETERS_HELP = {
         'type': "Type of the template. Use 'resource' for templates needed at the provision time when provisioning resources required by the application to run such as SQS queus, SNS topics, and CI/CD piplines.\nUse 'package' for templates needed at the build time when generating a package.\nUse 'release' for templates needed at the deploy time when generating a release." ,
         'key': "The key of the template",
         'limit': "Limit templates to be rendered.",
-        'render_path': "Path (relative to the root of the DSO application) where rendered template will be placed at.",
+        'render_path': "Path (relative to the root of the DSO application) where rendered template will be placed at. Use '**' and/or '*' to add the template dir name and base name to the render path.",
         'show_render_path': "Show render path",
     },
     'config': {
+        'key': "The key of the configuration",
         'value': 'Value for the configuration key',
         'input' : "Path to a local (yaml) file inputing the configuration. Use '-' to read from pipe/stdin.",
-        'uninherited': "Select only DSO configurations which are specific to the application, i.e. not inherited from the parent directories."
+        'local': "Select only the local DSO configurations, i.e. existing in the working directory.",
+        'global': "Select only the global DSO configurations, i.e. user-wide configuration.",
+        'init_local': "Explicitly override inherited configurations locally. If mixed with '-i' / '--input' option, it will casue the local configuration to be merged with the provided input configuration.",
+        'setup': "Run a setup wizard to assist configuring the DSO application.",
+
     }
 
 
@@ -91,13 +96,12 @@ CLI_PARAMETERS_HELP = {
 
 
 
-
 MESSAGES = {
     'InvalidKey': "'{0}' is an invalid key. Must conform to '{1}'",
     'ParameterNotFound': "Parameter '{0}' not found in the given context.",
     'SecretNotFound': "Secret '{0}' not found in the given context.",
     # 'ParameterNotFoundScope': "'{0}' not found as a parameter, but found a scope.",
-    'InvalidContext': "'{0}' is not a valid context. Must conform to '{1}'.",
+    'InvalidStage': "'{0}' is not a valid stage name. Valid form is <string>[/number], where it must conform to '{1}'.",
     'DSOConfigNotFound': 'DSO application configuration not found.',
     'ContextNotFound': "Context '{0}' not found.",
     'PatternNotMatched': "'{0}' is invalid. Must conform to '{1}'",
@@ -110,7 +114,6 @@ MESSAGES = {
     'TemplateNotFound': "Template '{0}' not found.",
     'InvalidTemplateKey': "'{0}' is an invalid template key. Must conform to '{1}'",
     'ContextNotFoundListingInherited': "Context '{0}' not found, listing inherited parameters if any.",
-    'AbsTemplateRenderPath': "Templae render path must be relative to the root of the DSO application.",
     'TryHelpWithCommand': "Try '{0} --help' for more details.",
     'TryHelp': "Try the command with '-h' / '--help' option for more details.",
     'InvalidJsonFile': "Invalid json file.",
@@ -130,6 +133,9 @@ MESSAGES = {
     'ProviderNotSet': "{0} provider has not been set.",
     'InvalidConfigOverrides': "Invalid DSO configuration overrides. Must conform to '<key>=<value>, ...'",
     'DSOConfigutrationOverriden': "DSO configuration '{0}' overriden to '{1}'.",
-    'DSOConfigFileNotFound': "DSO configuration not found at '{0}'.",
-    'EnteredSecretValuesNotMatched': "Entered values for the secret did not macth."
+    'NoDSOConfigFound': "No DSO configuration found in the working directory.",
+    'EnteredSecretValuesNotMatched': "Entered values for the secret did not macth.",
+    'InvalidRenderPath': "'{0}' is not a valid render path.",
+    'InvalidRenderPathExistingDir': "'{0}' is not a valid render path because it is an existing directory.",
+    'InvalidRenderPathAbs': "'{0}' is not a valid render path becasue render path must be relative to the root of the DSO application.",
 }
