@@ -7,7 +7,7 @@ import numbers
 from dsocli.logger import Logger
 from dsocli.config import Config
 from dsocli.parameters import ParameterProvider
-from dsocli.contexts import Contexts
+from dsocli.stages import Stages
 from dsocli.constants import *
 from dsocli.utils import *
 
@@ -48,7 +48,7 @@ class LocalParameterProvider(ParameterProvider):
     def __get_params_root_path(self, context=None):
         if not context:
             return f"{Config.working_dir}/{config['parameters_dir']}"
-        stage, env = Contexts.parse_context(context)
+        stage, env = Stages.parse_context(context)
         # if env == 'default':
         #     return f"{params_root_path}/{stage}"
         # else:
@@ -120,10 +120,10 @@ class LocalParameterProvider(ParameterProvider):
         fileExt = pathlib.Path(path).suffix
         if fileExt in ['.yml','.yaml']:
             with open(path, 'w') as outfile:
-                yaml.dump(data, outfile, default_flow_style=False)
+                yaml.dump(data, outfile, sort_keys=False, indent=2)
         else:
             with open(path, "w") as outfile: 
-                json.dump(data, outfile)
+                json.dump(data, outfile, sort_keys=False, indent=2)
 
 ###--------------------------------------------------------------------------------------------
 
@@ -151,12 +151,12 @@ class LocalParameterProvider(ParameterProvider):
     def __assert_param_file_exists(self, context, key):
         if context:
             if not self.__context_exists(context):
-                # raise Exception(MESSAGES['ContextNotFound'].format(context))
-                raise Exception(MESSAGES['ParameterNotFound'].format(key))
+                # raise DSOException(MESSAGES['ContextNotFound'].format(context))
+                raise DSOException(MESSAGES['ParameterNotFound'].format(key))
 
         if not self.__param_group_exists(context, key):
-            # raise Exception("Parameter group '{0}' not found.".format(self.__get_param_group_from_key(key)))
-            raise Exception(MESSAGES['ParameterNotFound'].format(key))
+            # raise DSOException("Parameter group '{0}' not found.".format(self.__get_param_group_from_key(key)))
+            raise DSOException(MESSAGES['ParameterNotFound'].format(key))
 
 ###--------------------------------------------------------------------------------------------
 
@@ -174,7 +174,7 @@ class LocalParameterProvider(ParameterProvider):
         ### first check if overide param file exists in context
         path = self.__get_param_file_path_from_key(context, key)
         if not path and context:
-            stage, env = Contexts.parse_context(context)
+            stage, env = Stages.parse_context(context)
             ### if not found, check default env in the stage
             if not env == 'defaut':
                 path = self.__get_param_file_path_from_key(f"{stage}/default", key)
@@ -209,7 +209,7 @@ class LocalParameterProvider(ParameterProvider):
         paramName = self.__get_param_name_from_key(key)
         set_dict_value(params, paramName.split('.'), value)
         with open(paramFilePath, 'w') as configFile:
-            yaml.dump(params, configFile, default_flow_style=False)
+            yaml.dump(params, configFile, sort_keys=False, indent=2)
 
 ###--------------------------------------------------------------------------------------------
 
@@ -246,7 +246,7 @@ class LocalParameterProvider(ParameterProvider):
                     grouppedParameters[group] = params
 
             if context: 
-                stage, env = Contexts.parse_context(context)
+                stage, env = Stages.parse_context(context)
                 
                 ### iterating through param files in stage(/default) and add them to paramDict
                 path = self.__get_params_root_path(f"{stage}/default")
@@ -318,13 +318,13 @@ class LocalParameterProvider(ParameterProvider):
     def get(self, context, key):
         path = self.__locate_param_file_from_key(context, key)
         if not path:
-                raise Exception(MESSAGES['ParameterNotFound'].format(key))
+                raise DSOException(MESSAGES['ParameterNotFound'].format(key))
         params = self.__load_param_file(path)
         value = get_dict_item(params, self.__get_param_name_from_key(key).split('.'))
         if value is None or isinstance(value, dict):
-            raise Exception(MESSAGES['ParameterNotFound'].format(key))
+            raise DSOException(MESSAGES['ParameterNotFound'].format(key))
         # if isinstance(value, dict):
-        #     raise Exception(MESSAGES['ParameterNotFoundScope'].format(key))
+        #     raise DSOException(MESSAGES['ParameterNotFoundScope'].format(key))
         return value
 
 ###--------------------------------------------------------------------------------------------
@@ -334,7 +334,7 @@ class LocalParameterProvider(ParameterProvider):
         params = self.__load_param_file_from_key(context, key)
         keys = self.__get_param_name_from_key(key).split('.')
         if not del_dict_item(params, keys):
-            raise Exception(MESSAGES['ParameterNotFound'].format(key))
+            raise DSOException(MESSAGES['ParameterNotFound'].format(key))
         ### recursively delet empty parent scopes 
         del_dict_empty_item(params, keys[:-1])
         path = self.__get_param_file_path_from_key(context, key)
